@@ -1,7 +1,7 @@
 import requests
 from urllib import parse
 from typing import List, Optional, Any
-from .model import VideoFile, Script, ScriptTemplate, Prompt, Project, Asset, User, VideoSearch, VideoFilters, DurationFilter, VideoEditCreate, VideoEditAsset, CustomPromptGeneration
+from .model import VideoFile, Script, ScriptTemplate, Prompt, Project, Asset, User, VideoSearch, VideoFilters, DurationFilter, VideoEditCreate, VideoEditAsset, CustomPromptGeneration, CropSettings
 from .utils import is_youtube_url
 import time
 from datetime import datetime
@@ -111,7 +111,42 @@ class ProjectsAPI:
             prompt_persona=prompt_persona if prompt_persona is not None else "",
             render_prompt=False
         )
-        return self.client._make_request("POST", f"/projects/{project_id}/{script_id}/generate", json=custom_prompt.model_dump())
+        return self.client._make_request("POST", f"/projects/{project_id}/{script_id}/prompt", json=custom_prompt.model_dump())
+    
+    def generate_with_custom_prompt(self, project_id: str, script_id: str, prompt: str, prompt_persona: Optional[str] = None, render_prompt: bool = False, **params):
+        '''
+        Generate a video asset using custom prompt and parameters
+        
+        Args:
+            project_id: UUID of the project
+            script_id: UUID of the script
+            prompt: The custom prompt text to use for generation
+            prompt_persona: Optional persona for the prompt
+            render_prompt: Whether to render the prompt statically (default: False)
+            **params: Additional query parameters (e.g., burn_subtitles, vj_media_gen, vj_video_1, vj_audio_1)
+            
+        Returns:
+            dict: Asset generation response containing asset_id, file_key, and asset_key
+        '''
+        custom_prompt = CustomPromptGeneration(
+            prompt=prompt,
+            prompt_persona=prompt_persona if prompt_persona is not None else "",
+            render_prompt=render_prompt
+        )
+        
+        # Build query parameters from kwargs
+        query_params = {k: str(v) for k, v in params.items() if v is not None}
+        
+        # Construct query string if params exist
+        query_string = ""
+        if query_params:
+            query_string = "?" + parse.urlencode(query_params)
+        
+        return self.client._make_request(
+            "POST", 
+            f"/projects/{project_id}/{script_id}/generate{query_string}",
+            json=custom_prompt.model_dump()
+        )
     
     def render_edit(self, project_id: str, create_edit: dict):
         '''
@@ -133,7 +168,7 @@ class ProjectsAPI:
         Create a new edit within a project for editing before rendering
         Returns same as above
         '''
-        return self.client._make_request("POST", f"/projects/{project_id}/create-edit", json=create_edit.model_dump_json())
+        return self.client._make_request("POST", f"/projects/{project_id}/create-edit", json=create_edit.model_dump())
     
     def get_edit(self, project_id: str, edit_id: str):
         '''
@@ -202,8 +237,6 @@ class AssetsAPI:
             uploaded = self.client._make_request("POST", upload_link["upload_url"]["url"], 
                                                 files={"file": (filename, file_object)})
         
-        # Update project data after upload and store reference to updated project
-        updated_project = self.client.projects.update_project_data(project_id)
         
         # Get the newly uploaded asset
         return self.get(uploaded["id"])
@@ -300,8 +333,8 @@ class VideoFileAPI:
             query_audio=query_audio,
             query_img=query_img
         )
-        # Make the request
-        return self.client._make_request("POST", "/video-file/search", json=vs.model_dump())
+        # Make the request - use mode='json' to ensure proper serialization
+        return self.client._make_request("POST", "/video-file/search", json=vs.model_dump(mode='json'))
     
     def download(self, video_id: str, filename: str):
         video = self.get(video_id)
@@ -435,8 +468,7 @@ class EditAPI:
         Create a new edit within a project for editing before rendering
         Returns same as above
         '''
-        return self.client._make_request("POST", f"/projects/{project_id}/create-edit", data=create_edit.model_dump_json(),
-                                         headers={"Content-Type": "application/json"})
+        return self.client._make_request("POST", f"/projects/{project_id}/create-edit", json=create_edit.model_dump())
 
     def create_edit_from_clips(
                     self, 
@@ -460,6 +492,10 @@ class EditAPI:
                 - type: Asset type (string, default: "videofile")
                 - start_time: Start time in 00:00:00.000 format (string)
                 - end_time: End time in 00:00:00.000 format (string)
+                - crop: Optional crop settings (dict) containing:
+                    - zoom: Zoom factor (float, default: 1.0, range: 0.1-10.0)
+                    - position_x: Horizontal offset (float, default: 0.0, range: -1.0 to 1.0)
+                    - position_y: Vertical offset (float, default: 0.0, range: -1.0 to 1.0)
             name: Optional name for the edit
             description: Optional description for the edit
             output_format: Output format (default: mp4)
@@ -480,6 +516,7 @@ class EditAPI:
             clip_type = clip.get("type", "videofile")
             start_time = clip.get("start_time")
             end_time = clip.get("end_time")
+            crop = clip.get("crop")
             
             # Validate required fields
             if not video_id:
@@ -495,13 +532,23 @@ class EditAPI:
             except ValueError:
                 raise ValueError(f"Invalid id: {video_id}")
             
+            # Create CropSettings if crop data is provided
+            crop_settings = None
+            if crop:
+                crop_settings = CropSettings(
+                    zoom=crop.get("zoom", 1.0),
+                    position_x=crop.get("position_x", 0.0),
+                    position_y=crop.get("position_y", 0.0)
+                )
+            
             # Create video asset
             video_asset = VideoEditAsset(
                 video_id=video_uuid,
                 type=clip_type,
                 video_start_time=start_time,
                 video_end_time=end_time,
-                audio_levels=[]  # Empty list as default
+                audio_levels=[],  # Empty list as default
+                crop=crop_settings
             )
             
             video_series.append(video_asset)
