@@ -70,7 +70,7 @@ class VideoFilters(BaseModel):
         if duration_min is not None or duration_max is not None:
             duration = DurationFilter(
                 min=duration_min if duration_min is not None else 0,
-                max=duration_max if duration_max is not None else float('inf')
+                max=duration_max if duration_max is not None else 99999999
             )
 
         return cls(
@@ -141,13 +141,10 @@ class VideoSearch(BaseModel):
                query_audio: Optional[str] = None,
                query_img: Optional[str] = None) -> 'VideoSearch':
         
-        if duration_min and duration_max and duration_min > duration_max:
-            dur = DurationFilter(min=duration_max, max=duration_min)
-        else:
-            dur = None
-        # Create filters if any filter parameters are provided
-        filters = VideoFilters(
-            duration=dur,
+        # Create filters using the proper create method
+        filters = VideoFilters.create(
+            duration_min=duration_min,
+            duration_max=duration_max,
             created_after=created_after,
             created_before=created_before,
             tags=tags,
@@ -263,6 +260,12 @@ class VideoEditAudioAsset(BaseModel):
         description="List of audio level measurements for this asset.",
     )
 
+class CropSettings(BaseModel):
+    """Crop/zoom settings for a video asset, similar to DaVinci Resolve"""
+    zoom: float = Field(1.0, ge=0.1, le=10.0, description="Zoom factor (1.0 = 100%, 1.5 = 150%, etc.)")
+    position_x: float = Field(0.0, ge=-1.0, le=1.0, description="Horizontal offset from center (-1.0 to 1.0)")
+    position_y: float = Field(0.0, ge=-1.0, le=1.0, description="Vertical offset from center (-1.0 to 1.0)")
+
 class VideoEditAsset(BaseModel):
     """Model representing a video asset in an edit sequence."""
     video_id: UUID = Field(
@@ -290,6 +293,11 @@ class VideoEditAsset(BaseModel):
         title="Audio Levels",
         description="List of audio level measurements for this video segment (0..1).",
     )
+    crop: Optional[CropSettings] = Field(
+        None,
+        title="Crop Settings",
+        description="Optional crop/zoom settings for this video segment.",
+    )
 
 class VideoEditCreate(BaseModel):
     """Model representing the creation parameters for a video edit."""
